==> wp-vuetojs-1.0.15.tgz: package/libs/vue-loader.js <==
const compilerTem = require('vue-template-compiler');
const fs = require('fs');
const sass = require('sass');
const path = require('path');
module.exports = {
  init(filePath,backFun){
    //创建name
    let fileName = path.basename(filePath).replace(".vue","");
    let className = "data-"+fileName;
    //template
    function createTemplate (content) {
      content = content.trim();
      let bqObj = /<(?:[^"'>]|"[^"]*"|'[^']*')*>/g.exec(content);
      let bq = bqObj[0];
      let index = bqObj.index;
      let bsObj = /<[\w]+/g.exec(content);
      let indexClass = bsObj.index + bsObj[0].length;
      indexClassRe = index+indexClass;
      content = content.substring(0,indexClassRe) + " " +className + " " + content.substr(indexClassRe)
      return content;
    }

    //javascript
    function createJavascript (content,template) {
      content = content.trim();
      let zuokuo = content.indexOf("{");
      if(!~zuokuo){
        return "";
      }
      content = content.substring(zuokuo,content.length);
      content = content.substring(0,1) + "\ntemplate:`"+template+"`,"+content.substring(1,content.length);
      return content;
    }
    //css
    function createCss (contents,back) {
      let zong = [];
      let pZong = [];
      contents.map(num=>{
        pZong.push(new Promise(function (resolve,reject) {
          let datas = "";
          let contentOne = num.content;
          contentOne = contentOne.trim();
          let {scoped,root} = num.attrs;
          if(scoped&&!root){
            datas = "["+className+"]{"+contentOne+"}"
          }else if(scoped&&root){
            datas = "["+className+"]"+contentOne
          }else{
            datas = contentOne;
          }
          const renderConfig = {
            data: datas
          }
          renderConfig.indentedSyntax = false;
          res = sass.render(renderConfig,(err,result)=>{
            if(err){
              reject(err)
            }else{
              resolve(result);
            }
          })
          // zong.push(res.css.toString('utf-8'));
        }))
      })
      Promise.all(pZong).then(function (res) {
        back(false,res.map(num=>num.css).join("\n"));
      }).catch(function (reason) {
        back(reason);
      })
    }
    try{
      let datas = fs.readFileSync(filePath,"utf-8");
      let returns = compilerTem.parseComponent(datas);
      let tem = createTemplate(returns.template.content);
      let scripts = createJavascript(returns.script.content,tem);
      let name = fileName;
      let zongOut = `Vue.component("${name}", ${scripts});`
      createCss(returns.styles,(err,cssR)=>{
        if(err){
          backFun(err);
        }else{
          zongOut+=`\nvuetojsAddClass(\`${cssR}\`)`;
          backFun(false,zongOut);
        }
      });
    }catch(e){
      //TODO handle the exception
      backFun(e);
    }
  }
}

==> wp-vuetojs-1.0.19.tgz: package/libs/vue-loader.js <==
const compilerTem = require('vue-template-compiler');
const fs = require('fs');
const sass = require('sass');
const path = require('path');
module.exports = {
  init(filePath,backFun){
    //创建name
    let fileName = path.basename(filePath).replace(".vue","");
    let className = "data-"+fileName;
    //template
    function createTemplate (content) {
      content = content.trim();
      let bqObj = /<(?:[^"'>]|"[^"]*"|'[^']*')*>/g.exec(content);
      let bq = bqObj[0];
      let index = bqObj.index;
      let bsObj = /<[\w]+/g.exec(content);
      let indexClass = bsObj.index + bsObj[0].length;
      indexClassRe = index+indexClass;
      content = content.substring(0,indexClassRe) + " " +className + " " + content.substr(indexClassRe)
      return content;
    }

    //javascript
    function createJavascript (content,template) {
      content = content.trim();
      let zuokuo = content.indexOf("{");
      if(!~zuokuo){
        return "";
      }
      content = content.substring(zuokuo,content.length);
      content = content.substring(0,1) + "\ntemplate:`"+template+"`,"+content.substring(1,content.length);
      return content;
    }
    //css
    function createCss (contents,back) {
      let zong = [];
      let pZong = [];
      contents.map(num=>{
        pZong.push(new Promise(function (resolve,reject) {
          let datas = "";
          let contentOne = num.content;
          contentOne = contentOne.trim();
          let {root} = num.attrs;
          if(!root){
            datas = "["+className+"]{"+contentOne+"}"
          }else{
            datas = "["+className+"]"+contentOne
          }
          const renderConfig = {
            data: datas
          }
          renderConfig.indentedSyntax = false;
          res = sass.render(renderConfig,(err,result)=>{
            if(err){
              reject(err)
            }else{
              resolve(result);
            }
          })
          // zong.push(res.css.toString('utf-8'));
        }))
      })
      Promise.all(pZong).then(function (res) {
        back(false,res.map(num=>num.css).join("\n"));
      }).catch(function (reason) {
        back(reason);
      })
    }
    try{
      let datas = fs.readFileSync(filePath,"utf-8");
      let returns = compilerTem.parseComponent(datas);
      let tem = createTemplate(returns.template.content);
      let scripts = createJavascript(returns.script.content,tem);
      let name = fileName;
      let zongOut = `Vue.component("${name}", ${scripts});`
      createCss(returns.styles,(err,cssR)=>{
        if(err){
          backFun(err);
        }else{
          zongOut+=`\nvuetojsAddClass(\`${cssR}\`)`;
          backFun(false,zongOut);
        }
      });
    }catch(e){
      //TODO handle the exception
      backFun(e);
    }
  }
}
